pub struct ProveZKOutput<F: Field> {
pub multilinear_evals: Vec<F>,
pub mask_eval: F,
pub challenges: Vec<F>,
}Expand description
Output of the ZK MLE-check proving protocol.
Fields
multilinear_evals: Vec<F>Evaluations of the main multilinear polynomials at the challenge point.
mask_eval: FEvaluation of the mask polynomial at the challenge point.
challenges: Vec<F>Verifier challenges for each round of the sumcheck protocol.