pub struct MleCheckMaskProver<F: Field, P: PackedField<Scalar = F>, Data: Deref<Target = [P]>> { /* private fields */ }Expand description
Prover for the Libra mask polynomial in ZK MLE-check.
The mask polynomial has the separable form $g(X_0, …, X_{n-1}) = sum_{i} g_i(X_i)$, where each $g_i$ is a univariate polynomial of configurable degree.
This structure allows efficient round polynomial computation in O(degree) time per round.
Implementations
Sourceimpl<F: Field, P: PackedField<Scalar = F>, Data: Deref<Target = [P]>> MleCheckMaskProver<F, P, Data>
impl<F: Field, P: PackedField<Scalar = F>, Data: Deref<Target = [P]>> MleCheckMaskProver<F, P, Data>
Sourcepub fn new(mask: Mask<P, Data>, eval_point: Vec<F>, eval_claim: F) -> Self
pub fn new(mask: Mask<P, Data>, eval_point: Vec<F>, eval_claim: F) -> Self
Creates a new prover for the Libra mask polynomial.
Arguments
mask- The mask polynomial (takes ownership).eval_point- The evaluation point z for the MLE-check claim, in high-to-low order.eval_claim- The claimed value of the MLE of g at the evaluation point.
Panics
Panics if mask.n_vars() != eval_point.len().